@@ -734,7 +734,8 @@ bool Create_json_table::finalize(THD *thd, TABLE *table,
 
   table->db_stat= HA_OPEN_KEYFILE;
   if (unlikely(table->file->ha_open(table, table->s->path.str, O_RDWR,
-                                    HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE)))
+                                    HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE |
+                                    HA_OPEN_SIZE_TRACKING)))
     DBUG_RETURN(true);
 
   table->set_created();
@@ -783,8 +784,7 @@ bool Create_json_table::add_json_table_fields(THD *thd, TABLE *table,
 
     while ((jc2= it2++) != jc)
     {
-      if (lex_string_cmp(system_charset_info,
-            &sql_f->field_name, &jc2->m_field->field_name) == 0)
+      if (sql_f->field_name.streq(jc2->m_field->field_name))
       {
         my_error(ER_DUP_FIELDNAME, MYF(0), sql_f->field_name.str);
         goto err_exit;
@@ -925,7 +925,10 @@ int Json_table_column::set(THD *thd, enum_type ctype, const LEX_CSTRING &path,
     return set(thd, ctype, path, nullptr);
 
   CHARSET_INFO *tmp;
-  if (!(tmp= cl.resolved_to_character_set(&my_charset_utf8mb4_general_ci)))
+  if (!(tmp= cl.resolved_to_character_set(
+                  thd,
+                  thd->variables.character_set_collations,
+                  &my_charset_utf8mb4_general_ci)))
     return 1;
   return set(thd, ctype, path, tmp);
 }
